@@ -1,13 +1,13 @@
 package     # hide from PAUSE
     DBIx::Class::Admin::Usage;
 
-use warnings;
-use strict;
 
 use base 'Getopt::Long::Descriptive::Usage';
 
 use base 'Class::Accessor::Grouped';
 
+use Class::C3;
+
 __PACKAGE__->mk_group_accessors('simple', 'synopsis', 'short_description');
 
 sub prog_name {
@@ -60,7 +60,6 @@ sub pod_option_text {
   foreach my $opt (@options) {
     my $spec = $opt->{spec};
     my $desc = $opt->{desc};
-    next if ($desc eq 'hidden');
     if ($desc eq 'spacer') {
         $string .= "=back\n\n=head2 $spec\n\n=cut\n\n=over\n\n";
         next;
@@ -68,7 +67,7 @@ sub pod_option_text {
 
     $spec = Getopt::Long::Descriptive->_strip_assignment($spec);
     $string .= "=item " . join " or ", map { length > 1 ? "B<--$_>" : "B<-$_>" }
-                             split /\|/, $spec;
+                             split /\|/, $spec; 
     $string .= "\n\n$desc\n\n=cut\n\n";
 
   }
